@@ -513,8 +513,10 @@ void create_context_menu (GdkEventButton *event)
                     g_autofree gchar *menu_item_txt = g_strdup_printf (
                                                                        (exp_status_changes_cnt == CM_RECURSIVELY) ? ( (number_of_selected_rows == 1) ? _("Expand Row Recursively") : _("Expand Rows Recursively") ) : 
                                                                        (
-                                                                        (exp_status_changes_cnt == CM_IMMEDIATE) ? ( (number_of_selected_rows == 1) ? _("Expand Row (Imd. Ch. Only)") : _("Expand Rows (Imd. Ch. Only)") ) : 
-																	   // Translation note: "Imd. Ch. Only" means "immediate children only""
+                                                                        // Translation note: "Imd. Ch. Only" means "immediate children only"
+                                                                        (exp_status_changes_cnt == CM_IMMEDIATE) ? ( (number_of_selected_rows == 1) ? _("Expand Row (Imd. Ch. Only)") : 
+                                                                        // Translation note: "Imd. Ch. Only" means "immediate children only"
+                                                                                                                                                      _("Expand Rows (Imd. Ch. Only)") ) : 
                                                                                                                     (number_of_selected_rows == 1) ? _("Collapse Row") : _("Collapse Rows")
                                                                        )
                                                                       );
